Date: 01 4, 2002 11:22:23 AM

# lowercase

## Purpose

Pre action that succeeds if leaf token is all lowercase.

## Syntax

<fromRuleEltNumber,toRuleEltNumber>lowercase();

fromRuleEltNumber - type: int
toRuleEltNumber - type: int

## Returns

## Remarks

## Example

The action lowercase specifies that the first rule element (_xALPHA) must be a word in all lowercase letters in order to be reduced to the suggested node _noun.

@PRE
<1,1>lowercase();

@RULES
_noun <- _xALPHA@@

## See Also

uppercase, cap, PRE Actions